(citation)=

# Citing tstrait

If you use `tstrait` in your research project, please cite the following paper:

- Daiki Tagami, Gertjan Bisschop, and Jerome Kelleher (2023),
  *tstrait: a quantitative trait simulator of tree sequence data*,

Bibtex records:
